summaryrefslogtreecommitdiffstats
path: root/bsps/include/bsp/irq-generic.h
diff options
context:
space:
mode:
Diffstat (limited to 'bsps/include/bsp/irq-generic.h')
-rw-r--r--bsps/include/bsp/irq-generic.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/bsps/include/bsp/irq-generic.h b/bsps/include/bsp/irq-generic.h
index 749dc78988..ad64c457d6 100644
--- a/bsps/include/bsp/irq-generic.h
+++ b/bsps/include/bsp/irq-generic.h
@@ -132,8 +132,8 @@ static inline rtems_vector_number bsp_interrupt_handler_index(
* @brief Generic BSP Interrupt Support
*
* The BSP interrupt support manages a sequence of interrupt vector numbers
* ranging from zero to @ref BSP_INTERRUPT_VECTOR_MAX
* including the end points. It provides methods to
* @ref bsp_interrupt_handler_install() "install",
* @ref bsp_interrupt_handler_remove() "remove" and
* @ref bsp_interrupt_handler_dispatch() "dispatch" interrupt handlers for each
@@ -144,7 +144,7 @@ static inline rtems_vector_number bsp_interrupt_handler_index(
*
* You have to configure the BSP interrupt support in the <bsp/irq.h> file
* for each BSP. For a minimum configuration you have to provide
- * @ref BSP_INTERRUPT_VECTOR_MAX.
+ * @ref BSP_INTERRUPT_VECTOR_COUNT.
*
* For boards with small memory requirements you can define
* @ref BSP_INTERRUPT_USE_INDEX_TABLE. With an enabled index table the handler
@@ -179,7 +179,7 @@ static inline rtems_vector_number bsp_interrupt_handler_index(
*/
static inline bool bsp_interrupt_is_valid_vector(rtems_vector_number vector)
{
- return vector <= (rtems_vector_number) BSP_INTERRUPT_VECTOR_MAX;
+ return vector < (rtems_vector_number) BSP_INTERRUPT_VECTOR_COUNT;
}
#endif
@@ -132,8 +132,8 @@ static inline rtems_vector_number bsp_interrupt_handler_index(
*
* The BSP interrupt support manages a sequence of interrupt vector numbers
- * ranging from zero to @ref BSP_INTERRUPT_VECTOR_MAX
- * including the end points. It provides methods to
+ * greater than or equal to zero and less than @ref BSP_INTERRUPT_VECTOR_COUNT
+ * It provides methods to
* @ref bsp_interrupt_handler_install() "install",
* @ref bsp_interrupt_handler_remove() "remove" and